X-Git-Url: https://git.mdrn.pl/redakcja.git/blobdiff_plain/6422710d756f21201737623ee51d61431cd4e0c9..449281d64b3c908fdb3622923a0d42f3942da3de:/apps/cover/forms.py?ds=inline
diff --git a/apps/cover/forms.py b/apps/cover/forms.py
index fdd43048..e6ffdff4 100755
--- a/apps/cover/forms.py
+++ b/apps/cover/forms.py
@@ -6,13 +6,37 @@
import re
from urllib2 import urlopen
from django import forms
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import ugettext_lazy as _, ugettext
from cover.models import Image
+from django.utils.text import mark_safe
class ImageAddForm(forms.ModelForm):
class Meta:
model = Image
+ def __init__(self, *args, **kwargs):
+ super(ImageAddForm, self).__init__(*args, **kwargs)
+ self.fields['file'].required = False
+
+ def clean_download_url(self):
+ cl = self.cleaned_data['download_url'] or None
+ if cl is not None:
+ try:
+ img = Image.objects.get(download_url=cl)
+ except Image.DoesNotExist:
+ pass
+ else:
+ raise forms.ValidationError(mark_safe(
+ ugettext('Image already in repository.'
+ ) % {'url': img.get_absolute_url()}))
+ return cl
+
+ def clean(self):
+ cleaned_data = super(ImageAddForm, self).clean()
+ if not cleaned_data.get('download_url', None) and not cleaned_data.get('file', None):
+ raise forms.ValidationError('No image specified')
+ return cleaned_data
+
class ImageEditForm(forms.ModelForm):
"""Form used for editing a Book."""
class Meta:
@@ -21,7 +45,7 @@ class ImageEditForm(forms.ModelForm):
class ReadonlyImageEditForm(ImageEditForm):
"""Form used for not editing a Book."""
def __init__(self, *args, **kwargs):
ret = super(ReadonlyImageEditForm, self).__init__(*args, **kwargs)
@@ -37,15 +61,18 @@ class FlickrForm(forms.Form):
source_url = forms.URLField(label=_('Flickr URL'))
def clean_source_url(self):
+ def normalize_html(html):
+ return re.sub('[\t\n]', '', html)
+
url = self.cleaned_data['source_url']
- m = re.match(r'(https?://)?(www\.|secure\.)?flickr\.com/photos/(?P[^/]+)/(?P\d+)', url)
+ m = re.match(r'(https?://)?(www\.|secure\.)?flickr\.com/photos/(?P[^/]+)/(?P\d+)/?', url)
if not m:
raise forms.ValidationError("It doesn't look like Flickr URL.")
author_slug, img_id = m.group('author'), m.group('img')
base_url = "https://www.flickr.com/photos/%s/%s/" % (author_slug, img_id)
try:
- html = urlopen(url).read().decode('utf-8')
+ html = normalize_html(urlopen(url).read().decode('utf-8'))
except:
raise forms.ValidationError('Error reading page.')
match = re.search(r'Some rights reserved', html)
@@ -53,14 +80,14 @@ class FlickrForm(forms.Form):
assert match
license_url = match.group(1)
self.cleaned_data['license_url'] = license_url
- re_license = re.compile(r'http://creativecommons.org/licenses/([^/]*)/([^/]*)/.*')
+ re_license = re.compile(r'https?://creativecommons.org/licenses/([^/]*)/([^/]*)/.*')
m = re_license.match(license_url)
assert m
self.cleaned_data['license_name'] = 'CC %s %s' % (m.group(1).upper(), m.group(2))
except AssertionError:
raise forms.ValidationError('Error reading license name.')
- m = re.search(r'By ([^<]*)', html)
+ m = re.search(r'"ownername":"([^"]*)', html)
if m:
self.cleaned_data['author'] = "%s@Flickr" % m.group(1)
else:
@@ -72,7 +99,7 @@ class FlickrForm(forms.Form):
self.cleaned_data['title'] = m.group(1)
url_size = base_url + "sizes/o/"
- html = urlopen(url_size).read().decode('utf-8')
+ html = normalize_html(urlopen(url_size).read().decode('utf-8'))
m = re.search(r'\s*
@@ -21,7 +45,7 @@ class ImageEditForm(forms.ModelForm):
class ReadonlyImageEditForm(ImageEditForm):
- """Form used for not editing a Book."""
+ """Form used for not editing an Image."""
def __init__(self, *args, **kwargs):
ret = super(ReadonlyImageEditForm, self).__init__(*args, **kwargs)